@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from django.conf.urls import patterns
+from __future__ import unicode_literals
 
 from coop_bar.bar import CoopBar
 
+urlpatterns = []
 
 bar = CoopBar()  # This is a Borg
-
-urlpatterns = patterns('')
\ No newline at end of file
